# coding: utf-8

"""
DEX AI API

API for DEX AI

The version of the OpenAPI document: 2.0.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from crypticorn.dex.client.models.website import Website
from typing import Set
from typing_extensions import Self


class Info(BaseModel):
    """
    Info
    """  # noqa: E501

    image_url: Optional[StrictStr] = None
    header: Optional[StrictStr] = None
    open_graph: Optional[StrictStr] = None
    websites: Optional[List[Website]] = Field(
        default=None, description="List of related websites"
    )
    __properties: ClassVar[List[str]] = [
        "image_url",
        "header",
        "open_graph",
        "websites",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Info from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in websites (list)
        _items = []
        if self.websites:
            for _item_websites in self.websites:
                if _item_websites:
                    _items.append(_item_websites.to_dict())
            _dict["websites"] = _items
        # set to None if image_url (nullable) is None
        # and model_fields_set contains the field
        if self.image_url is None and "image_url" in self.model_fields_set:
            _dict["image_url"] = None

        # set to None if header (nullable) is None
        # and model_fields_set contains the field
        if self.header is None and "header" in self.model_fields_set:
            _dict["header"] = None

        # set to None if open_graph (nullable) is None
        # and model_fields_set contains the field
        if self.open_graph is None and "open_graph" in self.model_fields_set:
            _dict["open_graph"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Info from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "image_url": obj.get("image_url"),
                "header": obj.get("header"),
                "open_graph": obj.get("open_graph"),
                "websites": [Website.from_dict(_item) for _item in obj["websites"]]
                if obj.get("websites") is not None
                else None,
            }
        )
        return _obj
