# coding: utf-8

"""
Indicator API

API for Indicator Data about the crypto market

The version of the OpenAPI document: 1.0.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import (
    BaseModel,
    ConfigDict,
    Field,
    StrictFloat,
    StrictInt,
    StrictStr,
    field_validator,
)
from typing import Any, ClassVar, Dict, List, Union
from typing import Optional, Set
from typing_extensions import Self


class PredictionCreate(BaseModel):
    """
    Prediction create model
    """  # noqa: E501

    symbol: StrictStr = Field(description="The symbol of the prediction")
    timestamp: StrictInt = Field(description="The timestamp of the prediction creation")
    version: StrictStr = Field(description="The version of the AI model")
    p10: List[Union[StrictFloat, StrictInt]] = Field(
        description="The 10th percentile of the prediction. List of 24 values in 15 minutes intervals."
    )
    p30: List[Union[StrictFloat, StrictInt]] = Field(
        description="The 30th percentile of the prediction. List of 24 values in 15 minutes intervals."
    )
    p50: List[Union[StrictFloat, StrictInt]] = Field(
        description="The 50th percentile of the prediction. List of 24 values in 15 minutes intervals."
    )
    p70: List[Union[StrictFloat, StrictInt]] = Field(
        description="The 70th percentile of the prediction. List of 24 values in 15 minutes intervals."
    )
    p90: List[Union[StrictFloat, StrictInt]] = Field(
        description="The 90th percentile of the prediction. List of 24 values in 15 minutes intervals."
    )
    __properties: ClassVar[List[str]] = [
        "symbol",
        "timestamp",
        "version",
        "p10",
        "p30",
        "p50",
        "p70",
        "p90",
    ]

    @field_validator("version")
    def version_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(["1.4", "1.5"]):
            raise ValueError("must be one of enum values ('1.4', '1.5')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PredictionCreate from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PredictionCreate from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "symbol": obj.get("symbol"),
                "timestamp": obj.get("timestamp"),
                "version": obj.get("version"),
                "p10": obj.get("p10"),
                "p30": obj.get("p30"),
                "p50": obj.get("p50"),
                "p70": obj.get("p70"),
                "p90": obj.get("p90"),
            }
        )
        return _obj
