# coding: utf-8

# flake8: noqa

"""
DEX AI API

API for DEX AI

The version of the OpenAPI document: 2.0.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

__version__ = "1.0.0"

# Define package exports
__all__ = [
    "SignalsApi",
    "StatusApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "ErrorResponse",
    "Info",
    "Liquidity",
    "PaginatedResponseSignalWithToken",
    "PriceChange",
    "SignalOverviewStats",
    "SignalWithToken",
    "Token",
    "TokenData",
    "TxnCounts",
    "Txns",
    "Volume",
    "Website",
]

# import apis into sdk package
from crypticorn.dex.client.api.signals_api import SignalsApi as SignalsApi
from crypticorn.dex.client.api.status_api import StatusApi as StatusApi

# import ApiClient
from crypticorn.dex.client.api_response import ApiResponse as ApiResponse
from crypticorn.dex.client.api_client import ApiClient as ApiClient
from crypticorn.dex.client.configuration import Configuration as Configuration
from crypticorn.dex.client.exceptions import OpenApiException as OpenApiException
from crypticorn.dex.client.exceptions import ApiTypeError as ApiTypeError
from crypticorn.dex.client.exceptions import ApiValueError as ApiValueError
from crypticorn.dex.client.exceptions import ApiKeyError as ApiKeyError
from crypticorn.dex.client.exceptions import ApiAttributeError as ApiAttributeError
from crypticorn.dex.client.exceptions import ApiException as ApiException

# import models into sdk package
from crypticorn.dex.client.models.error_response import ErrorResponse as ErrorResponse
from crypticorn.dex.client.models.info import Info as Info
from crypticorn.dex.client.models.liquidity import Liquidity as Liquidity
from crypticorn.dex.client.models.paginated_response_signal_with_token import (
    PaginatedResponseSignalWithToken as PaginatedResponseSignalWithToken,
)
from crypticorn.dex.client.models.price_change import PriceChange as PriceChange
from crypticorn.dex.client.models.signal_overview_stats import (
    SignalOverviewStats as SignalOverviewStats,
)
from crypticorn.dex.client.models.signal_with_token import (
    SignalWithToken as SignalWithToken,
)
from crypticorn.dex.client.models.token import Token as Token
from crypticorn.dex.client.models.token_data import TokenData as TokenData
from crypticorn.dex.client.models.txn_counts import TxnCounts as TxnCounts
from crypticorn.dex.client.models.txns import Txns as Txns
from crypticorn.dex.client.models.volume import Volume as Volume
from crypticorn.dex.client.models.website import Website as Website
