# coding: utf-8

# flake8: noqa
"""
Indicator API

API for Indicator Data about the crypto market

The version of the OpenAPI document: 1.0.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

# import models into model package
from crypticorn.indicator.client.models.economic_news_entry import EconomicNewsEntry
from crypticorn.indicator.client.models.error_response import ErrorResponse
from crypticorn.indicator.client.models.fn_g_entry import FnGEntry
from crypticorn.indicator.client.models.paginated_response_economic_news_entry import (
    PaginatedResponseEconomicNewsEntry,
)
from crypticorn.indicator.client.models.polymarket_prediction import (
    PolymarketPrediction,
)
from crypticorn.indicator.client.models.prediction import Prediction
from crypticorn.indicator.client.models.prediction_create import PredictionCreate
