# coding: utf-8

# flake8: noqa

"""
Klines Service API

API for retrieving OHLCV data, funding rates, and symbol information from Binance.

The version of the OpenAPI document: 1.0.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

__version__ = "1.0.0"

# Define package exports
__all__ = [
    "ChangeInTimeframeApi",
    "FundingRatesApi",
    "OHLCVDataApi",
    "StatusApi",
    "SymbolsApi",
    "UDFApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "ChangeInTimeframe",
    "ErrorResponse",
    "FundingRate",
    "FundingRateResponse",
    "OHLCV",
    "SearchSymbol",
    "SymbolGroup",
    "SymbolInfo",
    "SymbolType",
    "UDFConfig",
]

# import apis into sdk package
from crypticorn.klines.client.api.change_in_timeframe_api import (
    ChangeInTimeframeApi as ChangeInTimeframeApi,
)
from crypticorn.klines.client.api.funding_rates_api import (
    FundingRatesApi as FundingRatesApi,
)
from crypticorn.klines.client.api.ohlcv_data_api import OHLCVDataApi as OHLCVDataApi
from crypticorn.klines.client.api.status_api import StatusApi as StatusApi
from crypticorn.klines.client.api.symbols_api import SymbolsApi as SymbolsApi
from crypticorn.klines.client.api.udf_api import UDFApi as UDFApi

# import ApiClient
from crypticorn.klines.client.api_response import ApiResponse as ApiResponse
from crypticorn.klines.client.api_client import ApiClient as ApiClient
from crypticorn.klines.client.configuration import Configuration as Configuration
from crypticorn.klines.client.exceptions import OpenApiException as OpenApiException
from crypticorn.klines.client.exceptions import ApiTypeError as ApiTypeError
from crypticorn.klines.client.exceptions import ApiValueError as ApiValueError
from crypticorn.klines.client.exceptions import ApiKeyError as ApiKeyError
from crypticorn.klines.client.exceptions import ApiAttributeError as ApiAttributeError
from crypticorn.klines.client.exceptions import ApiException as ApiException

# import models into sdk package
from crypticorn.klines.client.models.change_in_timeframe import (
    ChangeInTimeframe as ChangeInTimeframe,
)
from crypticorn.klines.client.models.error_response import (
    ErrorResponse as ErrorResponse,
)
from crypticorn.klines.client.models.funding_rate import FundingRate as FundingRate
from crypticorn.klines.client.models.funding_rate_response import (
    FundingRateResponse as FundingRateResponse,
)
from crypticorn.klines.client.models.ohlcv import OHLCV as OHLCV
from crypticorn.klines.client.models.search_symbol import SearchSymbol as SearchSymbol
from crypticorn.klines.client.models.symbol_group import SymbolGroup as SymbolGroup
from crypticorn.klines.client.models.symbol_info import SymbolInfo as SymbolInfo
from crypticorn.klines.client.models.symbol_type import SymbolType as SymbolType
from crypticorn.klines.client.models.udf_config import UDFConfig as UDFConfig
