# coding: utf-8

"""
Hive AI API

API for Hive AI model training and evaluation

The version of the OpenAPI document: 1.0.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictFloat, StrictInt
from typing import Any, ClassVar, Dict, List, Union
from typing import Optional, Set
from typing_extensions import Self


class BinaryEvaluation(BaseModel):
    """
    Pydantic model for binary evaluation
    """  # noqa: E501

    accuracy: Union[StrictFloat, StrictInt] = Field(description="Accuracy")
    roc_auc: Union[StrictFloat, StrictInt] = Field(description="ROC AUC")
    precision: Union[StrictFloat, StrictInt] = Field(description="Precision")
    recall: Union[StrictFloat, StrictInt] = Field(description="Recall")
    f1: Union[StrictFloat, StrictInt] = Field(description="F1 score")
    conf_matrix: List[List[StrictInt]] = Field(description="Confusion matrix")
    __properties: ClassVar[List[str]] = [
        "accuracy",
        "roc_auc",
        "precision",
        "recall",
        "f1",
        "conf_matrix",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of BinaryEvaluation from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of BinaryEvaluation from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "accuracy": obj.get("accuracy"),
                "roc_auc": obj.get("roc_auc"),
                "precision": obj.get("precision"),
                "recall": obj.get("recall"),
                "f1": obj.get("f1"),
                "conf_matrix": obj.get("conf_matrix"),
            }
        )
        return _obj
