# coding: utf-8

"""
DEX AI API

API for DEX AI

The version of the OpenAPI document: 2.0.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictFloat, StrictInt
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing import Set
from typing_extensions import Self


class PriceChange(BaseModel):
    """
    PriceChange
    """  # noqa: E501

    h24: Optional[Union[StrictFloat, StrictInt]] = Field(
        default=0.0, description="24-hour price change percentage"
    )
    h6: Optional[Union[StrictFloat, StrictInt]] = None
    h1: Optional[Union[StrictFloat, StrictInt]] = None
    m5: Optional[Union[StrictFloat, StrictInt]] = None
    __properties: ClassVar[List[str]] = ["h24", "h6", "h1", "m5"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PriceChange from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if h6 (nullable) is None
        # and model_fields_set contains the field
        if self.h6 is None and "h6" in self.model_fields_set:
            _dict["h6"] = None

        # set to None if h1 (nullable) is None
        # and model_fields_set contains the field
        if self.h1 is None and "h1" in self.model_fields_set:
            _dict["h1"] = None

        # set to None if m5 (nullable) is None
        # and model_fields_set contains the field
        if self.m5 is None and "m5" in self.model_fields_set:
            _dict["m5"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PriceChange from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "h24": obj.get("h24") if obj.get("h24") is not None else 0.0,
                "h6": obj.get("h6"),
                "h1": obj.get("h1"),
                "m5": obj.get("m5"),
            }
        )
        return _obj
