# coding: utf-8

# flake8: noqa

"""
Indicator API

API for Indicator Data about the crypto market

The version of the OpenAPI document: 1.0.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

__version__ = "1.0.0"

# Define package exports
__all__ = [
    "NewsApi",
    "PredictionsApi",
    "SentimentApi",
    "StatusApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "EconomicNewsEntry",
    "ErrorResponse",
    "FnGEntry",
    "PaginatedResponseEconomicNewsEntry",
    "PolymarketPrediction",
    "Prediction",
    "PredictionCreate",
]

# import apis into sdk package
from crypticorn.indicator.client.api.news_api import NewsApi as NewsApi
from crypticorn.indicator.client.api.predictions_api import (
    PredictionsApi as PredictionsApi,
)
from crypticorn.indicator.client.api.sentiment_api import SentimentApi as SentimentApi
from crypticorn.indicator.client.api.status_api import StatusApi as StatusApi

# import ApiClient
from crypticorn.indicator.client.api_response import ApiResponse as ApiResponse
from crypticorn.indicator.client.api_client import ApiClient as ApiClient
from crypticorn.indicator.client.configuration import Configuration as Configuration
from crypticorn.indicator.client.exceptions import OpenApiException as OpenApiException
from crypticorn.indicator.client.exceptions import ApiTypeError as ApiTypeError
from crypticorn.indicator.client.exceptions import ApiValueError as ApiValueError
from crypticorn.indicator.client.exceptions import ApiKeyError as ApiKeyError
from crypticorn.indicator.client.exceptions import (
    ApiAttributeError as ApiAttributeError,
)
from crypticorn.indicator.client.exceptions import ApiException as ApiException

# import models into sdk package
from crypticorn.indicator.client.models.economic_news_entry import (
    EconomicNewsEntry as EconomicNewsEntry,
)
from crypticorn.indicator.client.models.error_response import (
    ErrorResponse as ErrorResponse,
)
from crypticorn.indicator.client.models.fn_g_entry import FnGEntry as FnGEntry
from crypticorn.indicator.client.models.paginated_response_economic_news_entry import (
    PaginatedResponseEconomicNewsEntry as PaginatedResponseEconomicNewsEntry,
)
from crypticorn.indicator.client.models.polymarket_prediction import (
    PolymarketPrediction as PolymarketPrediction,
)
from crypticorn.indicator.client.models.prediction import Prediction as Prediction
from crypticorn.indicator.client.models.prediction_create import (
    PredictionCreate as PredictionCreate,
)
