# coding: utf-8

"""
Marketcap Service API

API for retrieving historical marketcap data, available exchanges, and indicators.

The version of the OpenAPI document: 1.0.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations

import json
from enum import Enum

from typing_extensions import Self


class TradingStatus(str, Enum):
    """
    Trading status indicators for market availability and lifecycle management.
    """

    """
    allowed enum values
    """
    ACTIVE = "ACTIVE"
    RETIRED = "RETIRED"
    EXPIRED = "EXPIRED"

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of TradingStatus from a JSON string"""
        return cls(json.loads(json_str))
